<?php

namespace Onestartup\Crm\DataTables;

use App\Interested;
use Yajra\DataTables\Services\DataTable;

class InterestedDataTable extends DataTable
{
    /**
     * Build DataTable class.
     *
     * @param mixed $query Results from query() method.
     * @return \Yajra\DataTables\DataTableAbstract
     */
    public function dataTable($query)
    {
        return datatables($query)
            ->addColumn('action', function(Interested $interested) {
                    return "<a href='".route('crm.show',$interested->id)."'>Ver Detalle</a>";
                });
            //->addColumn('action', 'interested.action');
    }

    /**
     * Get query source of dataTable.
     *
     * @param \App\Interested $model
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function query(Interested $model)
    {
        return $model->leftJoin("interested_details", 'interesteds.id', '=', 'interested_details.interested_id')->select(['interesteds.id','interesteds.name','interesteds.email', 'interesteds.phone','interesteds.landing','interesteds.origin','interesteds.created_at','interesteds.updated_at', 'interesteds.extra1', 'interesteds.extra2', 'interesteds.extra3', 'interesteds.extra4', 'interesteds.extra5', 'interested_details.browser', 'interested_details.browser_version', 'interested_details.devise', 'interested_details.devise_type', "interested_details.platform", "interested_details.platform_version", "interested_details.session_time"])->orderBy('id', 'desc');
    }

    /**
     * Optional method if you want to use html builder.
     *
     * @return \Yajra\DataTables\Html\Builder
     */
    public function html()
    {
        return $this->builder()
                    ->columns($this->getColumns())
                    ->parameters([
                        'dom'          => 'Bfrtip',
                        'buttons'      => ['excel', 'csv','reset', 'reload'],
                    ]);
    }

    /**
     * Get columns.
     *
     * @return array
     */
    protected function getColumns()
    {
        return [
            'id',
            'name',
            'email', 
            'phone',
            'landing',
            'origin',
            'created_at',
            'updated_at' => ['visible' => false],
            'extra1' => ['visible' => false],
            'extra2' => ['visible' => false],
            'extra3' => ['visible' => false],
            'extra4' => ['visible' => false],
            'extra5' => ['visible' => false],
            
            'browser' => ['visible' => false],
            'browser_version' => ['visible' => false],
            'devise' => ['visible' => false],
            'devise_type' => ['visible' => false],
            'platform' => ['visible' => false],
            'platform_version' => ['visible' => false],
            'session_time' => ['visible' => false],

            'action' => [ 'exportable' => false],
        ];
    }

    /**
     * Get filename for export.
     *
     * @return string
     */
    protected function filename()
    {
        return 'Interested_' . date('YmdHis');
    }
}
